==> update%20from%202.9.0%20to%202.9.1.zip: update/update-files/application/views/seller/pages/tables/manage-attribute.php <==
<div class="content-wrapper">
    <!-- Content Header (Page header) -->
    <!-- Main content -->
    <section class="content-header">
        <div class="container-fluid">
            <div class="row mb-2">
                <div class="col-sm-6">
                    <h4>Attribute</h4>
                </div>
                <div class="col-sm-6">
                    <ol class="breadcrumb float-sm-right">
                        <li class="breadcrumb-item"><a href="<?= base_url('seller/home') ?>">Home</a></li>
                        <li class="breadcrumb-item active">Attribute </li>
                    </ol>
                </div>
            </div>
        </div><!-- /.container-fluid -->
    </section>
    <section class="content">
        <div class="container-fluid">
            <div class="col-md-12 ">
                <div class="card content-area p-4">
                    <div class="card-innr">
                        <div class="card-head">
                            <h4 class="card-title">Attributes </h4>
                        </div>
                        <div class="gaps-1-5x"></div>
                        <table class='table-striped' id='category_table' data-toggle="table" data-url="<?= base_url('seller/attributes/attribute_list') ?>" data-click-to-select="true" data-side-pagination="server" data-pagination="true" data-page-list="[5, 10, 20, 50, 100, 200]" data-search="true" data-show-columns="true" data-show-refresh="true" data-trim-on-search="false" data-sort-name="id" data-sort-order="asc" data-mobile-responsive="true" data-toolbar="" data-show-export="true" data-maintain-selected="true" data-export-types='["txt","excel","csv"]' data-export-options='{
                        "fileName": "attributes-list",
                        "ignoreColumn": ["state"] 
                        }' data-query-params="queryParams">
                            <thead>
                                <tr>
                                    <th data-field="id" data-sortable="true">ID</th>
                                    <th data-field="attribute_set" data-sortable="true">Attribute Set</th>
                                    <th data-field="name" data-sortable="false">Name</th>
                                    <th data-field="status" data-sortable="false">Status</th>
                                </tr>
                            </thead>
                        </table>
                    </div><!-- .card-innr -->
                </div><!-- .card -->
            </div>
        </div>
        <!-- /.row -->
</div><!-- /.container-fluid -->
</section>
<!-- /.content -->
</div>

==> update%20from%202.10.1%20to%202.10.2.zip: update/update-files/application/views/seller/pages/tables/manage-attribute.php <==
<div class="content-wrapper">
    <!-- Content Header (Page header) -->
    <!-- Main content -->
    <section class="content-header">
        <div class="container-fluid">
            <div class="row mb-2">
                <div class="col-sm-6">
                    <h4>Attribute</h4>
                </div>
                <div class="col-sm-6">
                    <ol class="breadcrumb float-sm-right">
                        <li class="breadcrumb-item"><a href="<?= base_url('seller/home') ?>">Home</a></li>
                        <li class="breadcrumb-item active">Attribute </li>
                    </ol>
                </div>
            </div>
        </div><!-- /.container-fluid -->
    </section>
    <section class="content">
        <div class="container-fluid">
            <div class="col-md-12 ">
                <div class="card content-area p-4">
                    <div class="card-innr">
                        <div class="card-head">
                            <h4 class="card-title">Attributes </h4>
                        </div>
                        <div class="gaps-1-5x"></div>
                        <table class='table-striped' id='category_table' data-toggle="table" data-url="<?= base_url('seller/attributes/attribute_list') ?>" data-click-to-select="true" data-side-pagination="server" data-pagination="true" data-page-list="[5, 10, 20, 50, 100, 200]" data-search="true" data-show-columns="true" data-show-refresh="true" data-trim-on-search="false" data-sort-name="id" data-sort-order="desc" data-mobile-responsive="true" data-toolbar="" data-show-export="true" data-maintain-selected="true" data-export-types='["txt","excel","csv"]' data-export-options='{
                        "fileName": "attributes-list",
                        "ignoreColumn": ["state"] 
                        }' data-query-params="queryParams">
                            <thead>
                                <tr>
                                    <th data-field="id" data-sortable="true">ID</th>
                                    <th data-field="attribute_set" data-sortable="true">Attribute Set</th>
                                    <th data-field="name" data-sortable="false">Name</th>
                                    <th data-field="status" data-sortable="false">Status</th>
                                </tr>
                            </thead>
                        </table>
                    </div><!-- .card-innr -->
                </div><!-- .card -->
            </div>
        </div>
        <!-- /.row -->
</div><!-- /.container-fluid -->
</section>
<!-- /.content -->
</div>
